computeLimits: Compute plot limits

View source: R/data_plotting_utils.R

computeLimitsR Documentation

Compute plot limits

Description

Helper function to compute the axis limits of a plot with given x, y data and optionally a fixed x-y-ratio and correcting the latitude/longitude scale at different latitudes

Usage

computeLimits(xData, yData, xyRatio = 1, convertLatLong = TRUE, stretch = 1)

graphicalExtremes documentation built on March 30, 2026, 5:07 p.m.