make_sep_list: Create a list of separators

View source: R/graphs_functions.R

make_sep_listR Documentation

Create a list of separators

Description

Creates a list of separator set, such that every pair of non-adjacent vertices in graph is completely disconnected by the removal of (at least) one of the separator sets from the graph.

Usage

make_sep_list(graph, details = TRUE)

Arguments

graph

A graph

details

Return detailed infos (default TRUE)

Value

A list of numeric vectors


graphicalExtremes documentation built on March 30, 2026, 5:07 p.m.